@@ -1,12 +1,12 @@
-from vinca.lib import classes
-from vinca.lib import ansi
+from vinca.card import Card
+from vinca.generators.decorator import generator
 
-def generate(scrollback = True):
-	new_card = classes.Card(create=True)
+@generator
+def two_lines():
+	''' make a simple question and answer card '''
+	new_card = Card(create=True)
 	new_card.editor, new_card.reviewer, new_card.scheduler = 'two_lines', 'two_lines', 'base'
 	(new_card.path / 'front').touch()
 	(new_card.path / 'back').touch()
 	new_card.edit()
-	if scrollback:
-		ansi.up_line(2)
 	return [new_card]
