@@ -40,3 +40,18 @@ def _do(n=1, cmd=None):
 	print(codes[cmd]*n, end='', flush=True)
 for key in codes:
 	globals()[key] = functools.partial(_do, cmd=key)
+
+def strip_ansi(text):
+	ansi_escape = re.compile(r'''
+	    \x1B  # ESC
+	    (?:   # 7-bit C1 Fe (except CSI)
+		[@-Z\\-_]
+	    |     # or [ for CSI, followed by a control sequence
+		\[
+		[0-?]*  # Parameter bytes
+		[ -/]*  # Intermediate bytes
+		[@-~]   # Final byte
+	    )
+	''', re.VERBOSE)
+	result = ansi_escape.sub('', sometext)
+	return result
