@@ -6,13 +6,10 @@ import termios
 import sys
 import contextlib
 import os
+from types import SimpleNamespace
 
-ESC = '\x1b'
-UP = '\x1b[A'
-DOWN = '\x1b[B'
-RIGHT = '\x1b[C'
-LEFT = '\x1b[D'
-BACK = '\x7f'
+keys = SimpleNamespace(ESC = '\x1b', UP = '\x1b[A', DOWN = '\x1b[B', RIGHT = '\x1b[C',
+			LEFT = '\x1b[D', BACK = '\x7f', CTRL_R = '\x12')
 
 @contextlib.contextmanager
 def raw_terminal():
@@ -30,10 +27,4 @@ def raw_terminal():
 
 def readkey():
 	with raw_terminal() as fd:
-		ch = os.read(fd, 4).decode()
-
-		return ch
-
-
-
-
+		return os.read(fd, 4).decode()
