@@ -2,11 +2,11 @@
 # The parent module (reviewers/__init__.py) contatins some
 # generic code used by all of the reviewers.
 from vinca.lib import ansi
-import readchar 
 
 from vinca.lib.video import DisplayImage
 from vinca.lib.audio import Recording
 from vinca.lib.terminal import AlternateScreen
+from vinca.lib.readkey import readkey
 
 def make_string(card):
 	f = ' / '.join((card.path / 'front').read_text().splitlines())
@@ -26,12 +26,12 @@ def review(card):
 		# front media
 		with DisplayImage(card.path/'image_front'), Recording(card.path/'audio_front'):
 			# card flip
-			readchar.readchar() 
+			readkey()
 
 		back = '\n' + (card.path / 'back').read_text()
 		print(back)
 
 		with DisplayImage(card.path/'image_back'), Recording(card.path/'audio_back'):
-			key = readchar.readchar()
+			key = readkey()
 	
 	return key
