@@ -1,6 +1,6 @@
-import readchar 
 
 from vinca.lib.terminal import AlternateScreen
+from vinca.lib.readkey import readkey
 
 def make_string(card):
 	f = ' / '.join((card.path / 'front').read_text().splitlines())
@@ -15,7 +15,7 @@ def review(card):
 		print(front)
 		#TODO reveal tags
 
-		char = readchar.readchar() # press any key to flip the card
+		char = readkey() # press any key to flip the card
 		print('\n\n')
 		if char in ['x','a','q']: # immediate exit actions
 			return char
@@ -23,4 +23,4 @@ def review(card):
 		back = '\n' + (card.path / 'back').read_text()
 		print(back)
 	
-		return readchar.readchar()
+		return readkey()
